rm(list=ls()) # always good to wipe R's memory.

##############################################################################
# ANOVA, model selection, and pairwise contrasts among treatments using R.
##############################################################################
# Marco Plebani, December 20th, 2014.

# The golden steps:

# 1 - have a clear question
# 2 - design the study/experiment accordingly
# 3 - collect your data
# 4 - PLOT THE DATA and start doing qualitative interpretation
# 5 - test your initial question by defining the corresponding linear model
# 6 - assess if the model assumptions are respected (*)
# 7 - run the model in R
# 8 - see if the model is the most parsimonious uysing anova()
# 9 - evaluate differences among treatments using summary()

# (*) If they are not, modify the model accordingly.
# Examples:
# non-normally distributed data? --> use glm() instead of lm(), and specify the correct family distribution.
# non-independent data? --> use mixed effect models.

# DO NOT JUST "TRY STUFF IN R" until you get what you think you want!
# Follow the steps listed above, check, check again, make yourself familiar with the type of model used...
# In the following example I will stick to linear models.
##########################
# Example 1. One-way ANOVA
# Load data:
data(chickwts) # chickwts is one of the many data sets built in the R software by default. data() is a function specific for calling these datasets.
str(chickwts)
head(chickwts,10)
# THE QUESTION. Do chick weight differ if they are fed differently?
# PLOT THE DATA:
boxplot(weight ~ feed,
	data = chickwts,
	ylab="Weight (grams)")

# It seems there are differences among treatments. Let's check this statistically:
chick1 <- lm(weight ~ feed, data = chickwts)
par(mfrow=c(2,2)) # prepare a window with room for 4 plots
plot(chick1) # test the assumptions graphically
# LOOKS GOOD.
par(mfrow=c(1,1)) # back to default graphic setting
chick0 <- lm(weight ~ 1, data = chickwts) # the simplest model possible. It means that the weight of any chick has 95% probability of being within the overall mean of chick weights +/- their standard error.
# Which model is more parsimonious?
anova(chick1, chick0)
# This test checks if the more complex model explains significantly more variability than the simpler one.
# In this case the answer is yes, that is, adding information about the food provided to chicks allows more precise predictions on their body weight.

# Let's evaluate differences among treatments using summary()
summary(chick1)
chickwts$feed <- relevel(chickwts$feed, ref = "meatmeal")
# this does NOT change any data, it just tells R to consider the specified treatment as reference level in the summary.
# IMPORTANT! Re-run the linear model:
chick1 <- lm(weight ~ feed, data = chickwts)
summary(chick1)

